@@ -1,5 +1,3 @@
-# type: ignore
-
 """Configuration file for the Sphinx documentation builder.
 
 This file only contains a selection of the most common options. For a full
@@ -7,14 +5,14 @@ list see the documentation:
 https://www.sphinx-doc.org/en/master/usage/configuration.html
 """
 
-import dataclasses
 import os
 import shutil
 import subprocess
 import sys
-from typing import Union
 
-import sphinxcontrib.bibtex.plugin
+import requests
+
+# pyright: reportMissingImports=false
 from pkg_resources import get_distribution
 from pybtex.database import Entry
 from pybtex.plugin import register_plugin
@@ -31,24 +29,45 @@ from pybtex.style.template import (
     sentence,
     words,
 )
-from sphinxcontrib.bibtex.style.referencing import BracketStyle
 
 # -- Project information -----------------------------------------------------
 project = "AmpForm"
 package = "ampform"
 repo_name = "ampform"
-copyright = "2020, ComPWA"
+copyright = "2020, ComPWA"  # noqa: A001
 author = "Common Partial Wave Analysis"
 
 if os.path.exists(f"../src/{package}/version.py"):
     __release = get_distribution(package).version
     version = ".".join(__release.split(".")[:3])
 
+
+# -- Fetch logo --------------------------------------------------------------
+def fetch_logo(url: str, output_path: str) -> None:
+    if os.path.exists(output_path):
+        return
+    online_content = requests.get(url, allow_redirects=True)
+    with open(output_path, "wb") as stream:
+        stream.write(online_content.content)
+
+
+logo_path = "_static/logo.svg"
+try:
+    fetch_logo(
+        url="https://raw.githubusercontent.com/ComPWA/ComPWA/04e5199/doc/images/logo.svg",
+        output_path=logo_path,
+    )
+except requests.exceptions.ConnectionError:
+    pass
+if os.path.exists(logo_path):
+    html_logo = logo_path
+
 # -- Generate API ------------------------------------------------------------
 sys.path.insert(0, os.path.abspath("."))
-import abbreviate_signature
-import extend_docstrings
+import extend_docstrings  # noqa: E402
+from abbreviate_signature import abbreviate_signature  # noqa: E402
 
+abbreviate_signature()
 extend_docstrings.insert_math()
 
 shutil.rmtree("api", ignore_errors=True)
@@ -178,7 +197,7 @@ PYTHON_VERSION = f"{sys.version_info.major}.{sys.version_info.minor}"
 CONSTRAINTS_PATH = f"../.constraints/py{PYTHON_VERSION}.txt"
 with open(CONSTRAINTS_PATH) as stream:
     CONSTRAINTS = stream.read()
-RELEASES = dict()
+RELEASES = {}
 for line in CONSTRAINTS.split("\n"):
     line = line.split("#")[0]  # remove comments
     line = line.strip()
@@ -281,7 +300,7 @@ thebe_config = {
 
 # Specify bibliography style
 @node
-def et_al(children, data, sep="", sep2=None, last_sep=None):
+def et_al(children, data, sep="", sep2=None, last_sep=None):  # type: ignore[no-untyped-def]
     if sep2 is None:
         sep2 = sep
     if last_sep is None:
@@ -298,7 +317,7 @@ def et_al(children, data, sep="", sep2=None, last_sep=None):
 
 
 @node
-def names(children, context, role, **kwargs):
+def names(children, context, role, **kwargs):  # type: ignore[no-untyped-def]
     """Return formatted names."""
     assert not children
     try:
@@ -314,10 +333,10 @@ def names(children, context, role, **kwargs):
 
 
 class MyStyle(UnsrtStyle):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__(abbreviate_names=True)
 
-    def format_names(self, role, as_sentence=True) -> Node:
+    def format_names(self, role: Entry, as_sentence: bool = True) -> Node:
         formatted_names = names(
             role, sep=", ", sep2=" and ", last_sep=", and "
         )
@@ -326,7 +345,7 @@ class MyStyle(UnsrtStyle):
         else:
             return formatted_names
 
-    def format_eprint(self, e):
+    def format_eprint(self, e: Entry) -> Node:
         if "doi" in e.fields:
             return ""
         return super().format_eprint(e)
@@ -361,11 +380,11 @@ def remove_dashes_and_spaces(isbn: str) -> str:
     return isbn
 
 
-def remove_http(input: str) -> str:
+def remove_http(url: str) -> str:
     to_remove = ["https://", "http://"]
     for remove in to_remove:
-        input = input.replace(remove, "")
-    return input
+        url = url.replace(remove, "")
+    return url
 
 
 register_plugin("pybtex.style.formatting", "unsrt_et_al", MyStyle)
