@@ -16,6 +16,7 @@ The package also provides other helpful functions, like
 
 import inspect
 import logging
+import sys
 from collections import abc
 from typing import (
     Any,
@@ -39,6 +40,12 @@ try:
 except ImportError:
     PrettyPrinter = Any
 
+if sys.version_info >= (3, 10):
+    from typing import TypeGuard
+else:
+    from typing_extensions import TypeGuard
+
+
 Slider = Union[FloatSlider, IntSlider]
 RangeDefinition = Union[
     Tuple[float, float],
@@ -99,7 +106,7 @@ class SliderKwargs(abc.Mapping):
                     "arg_to_symbol"
                 )
         for name, slider in sliders.items():
-            if not isinstance(slider, Slider.__args__):  # type: ignore
+            if not isinstance(slider, Slider.__args__):  # type: ignore[attr-defined]
                 raise TypeError(
                     f'Slider "{name}" is not a valid ipywidgets slider'
                 )
@@ -185,11 +192,11 @@ class SliderKwargs(abc.Mapping):
                     f'Range definition for slider "{slider_name}" is not a tuple'
                 )
             slider = self[slider_name]
-            if len(range_def) == 2:
-                min_, max_ = range_def  # type: ignore
+            if _is_min_max(range_def):
+                min_, max_ = range_def
                 step_size = slider.step
-            elif len(range_def) == 3:
-                min_, max_, n_steps = range_def  # type: ignore
+            elif _is_min_max_step(range_def):
+                min_, max_, n_steps = range_def
                 if n_steps <= 0:
                     raise ValueError("Number of steps has to be positive")
                 if isinstance(n_steps, float):
@@ -211,6 +218,20 @@ class SliderKwargs(abc.Mapping):
                 slider.step = step_size
 
 
+def _is_min_max(range_def: RangeDefinition) -> TypeGuard[Tuple[float, float]]:
+    if len(range_def) == 2:
+        return True
+    return False
+
+
+def _is_min_max_step(
+    range_def: RangeDefinition,
+) -> TypeGuard[Tuple[float, float, Union[float, int]]]:
+    if len(range_def) == 3:
+        return True
+    return False
+
+
 ValueType = TypeVar("ValueType")
 
 
